@@ -5,8 +5,8 @@ use warnings;
 use parent qw(DataAccess::Broker);
 use DBI;
 use Gtk2::Ex::DbLinker::DbiDataManager;
-use Data::Dumper;
-use Carp 'croak';
+#use Data::Dumper;
+#use Carp 'croak';
 
 sub new {
     my ( $class, $href ) = @_;
@@ -40,9 +40,9 @@ sub query_DM {
     my $arg_ref = $self->get_arg_dbi( $key, $values_ref );
     $self->{log}->debug("query_DM values ", join(" ", @{$values_ref}));
     my $where = $arg_ref->{sql}->{where};
-    croak("sql->where not found") unless ( defined $where );
+    $self->{log}->logcroak("sql->where not found") unless ( defined $where );
     my $values =$arg_ref->{sql}->{bind_values};
-    croak("sql->bind_values not found") unless ( defined $values );
+    $self->{log}->logcroak("sql->bind_values not found") unless ( defined $values );
     $dman->query( where => $where, bind_values => $values );
 
 }
