@@ -6,7 +6,7 @@ use parent qw(DataAccess::Broker);
 use DBI;
 use Gtk2::Ex::DbLinker::SqlADataManager;
 use Data::Dumper;
-use Carp 'croak';
+# use Carp 'croak';
 
 sub new {
 
@@ -28,7 +28,7 @@ sub get_DM_for {
 my ($self, $key, $value_ref) = @_;
    my $arg_ref = $self->get_arg_sqla($key, $value_ref);
    my @ar = (%{ $arg_ref });
-   $self->{log}->debug("get_DM_for ", Dumper @ar);
+   $self->{log}->debug("get_DM_for ", sub{ Dumper @ar});
  my $dman =  Gtk2::Ex::DbLinker::SqlADataManager->new(
      dbh => $self->{dbh},
      @ar
@@ -41,9 +41,9 @@ sub query_DM {
     my ($self, $dman, $key, $values_ref) = @_;
     my $arg_ref = $self->get_arg_sqla($key, $values_ref);
     my $where =  $arg_ref->{select_param}->{-where};    
-     croak ("select_param->where not found") unless (defined $where);
+     $self->{log}->logcroak ("select_param->where not found") unless (defined $where);
      
-$self->{log}->debug("query_DM ", Dumper $where);
+$self->{log}->debug("query_DM ", sub { Dumper $where });
 
 $dman->query(-where => $where);
 
