@@ -11,10 +11,9 @@ use Wx::XRC;
 
 # use Wx::Perl::PubSub qw(:global);
 #se Gtk2::Ex::DbLinker::DbiDataManager;
-use Data::Dumper;
+# use Data::Dumper;
 use Wx::Perl::DbLinker::Wxdatasheet;
-
-use Carp qw( carp croak confess );
+#use Carp qw( carp croak confess );
 use Wx::Event qw(EVT_BUTTON EVT_MENU EVT_TEXT EVT_COMBOBOX);
 
 my %refs     = map { $_, 1 } qw(Wx::Perl::DbLinker::Wxdatasheet Wxdatasheet);
@@ -52,7 +51,7 @@ sub new {
         #$path = $href->{main_file};
         $self->{xrc} = Wx::XmlResource->new();
         $self->{xrc}->InitAllHandlers();
-        $self->{xrc}->Load($path) or confess("Can't load $path");
+        $self->{xrc}->Load($path) or $self->{log}->logconfess("Can't load $path");
         $self->{frame} = $self->{xrc}->LoadFrame( undef, $href->{main_name} );
         $self->{frame}->SetSize( $self->{size} );
 
@@ -113,7 +112,7 @@ sub set_form {
     my ( $self, $form ) = @_;
 
     # show_all($self);
-    croak("No instance found for set_form") unless ($form);
+    $self->{log}->logcroak("No instance found for set_form") unless ($form);
 
 #if ($dataref->isa('Gtk2::Ex::Datasheet::DBI') || $dataref->isa('Linker::Datasheet')){
     $self->{form} = $form;
@@ -171,14 +170,14 @@ sub load_panel {
     $xrc->InitAllHandlers();
 
     # $path = $self->_get_path($path);
-    $xrc->Load($path) or confess("Can't load xrc file from $path");
+    $xrc->Load($path) or $self->{log}->logconfess("Can't load xrc file from $path");
     my $top_from_xrc;
 
     $where = Wx::Window::FindWindowByName( $where_name, $self->{frame} );
 
     #print Dumper($where);
 
-    confess("Can't locate $where_name in wigdets tree") unless ($where);
+    $self->{log}->logconfess("Can't locate $where_name in wigdets tree") unless ($where);
 
     #this load top_name ?
     my $p = $xrc->LoadPanel( $where, $top_name )
@@ -187,7 +186,7 @@ sub load_panel {
 
 #$p = Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID($top_name) ) unless($p);
 #my $p = $top_from_xrc;
-    confess("Can't load $top_name") unless ($p);
+    $self->{log}->logconfess("Can't load $top_name") unless ($p);
     my $s = Wx::BoxSizer->new(wxVERTICAL);
 
     #$s->Layout();
@@ -205,7 +204,7 @@ sub load_panel {
 #
 sub load_grid {
     my ( $self, $argref ) = @_;
-    confess(
+    $self->{log}->logconfess(
         "Argument for loa_grid must be a hash with keys top_panel, dest_name, datasheet_param"
         )
         unless ( ref $argref eq "HASH"
@@ -218,7 +217,7 @@ sub load_grid {
     my $where =
         Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID($where_name),
         $top_panel );
-    confess( "Can't find any object named ",
+    $self->{log}->logconfess( "Can't find any object named ",
         $where_name, " to place the grid into" )
         unless ($where);
 
@@ -229,7 +228,7 @@ sub load_grid {
     my $sw = Wx::ScrolledWindow->new( $where, wxID_ANY )
         ; #,    Wx::Point->new(0, 0), Wx::Size->new(400, 400),  wxVSCROLL | wxHSCROLL);
     $sw->SetScrollbars( 1, 1, 1, 1 );
-    confess("Can't create sizer or scrolled window") unless ( $s && $sw );
+    $self->{log}->logconfess("Can't create sizer or scrolled window") unless ( $s && $sw );
     $s->Add( $sw, 1, wxALL | wxEXPAND, 1 );
     $where->SetSizer($s);
     $s = Wx::BoxSizer->new(wxVERTICAL);
@@ -256,12 +255,12 @@ sub m_tables_clicked {
 sub connect_signal_for {
     my ( $self, $wname, $sub_ref, $data ) = @_;
     my $w = $self->get_object($wname);
-    croak(
+    $self->{log}->logcroak(
         "Dnav connect_signal_for failed since no widget instance exists for $wname"
     ) unless ($w);
     my $name   = ref $w;
     my $signal = $signals{$name};
-    print Dumper($name);
+    # print Dumper($name);
     &$signal( $self->{frame}, $w, sub { &$sub_ref( $w, $data, @_ ); } );
 
 }
@@ -502,7 +501,7 @@ sub populate_widgets {
             . " isa control "
             . ( UNIVERSAL::isa( $w, 'Wx::Window' ) ? " true" : " false" ) )
         ; #, " ", ( $w->isa('Gtk2::Container') ? " is a container" : " is not a container"), "\n";
-    croak("widget undefined") unless $w;
+    $self->{log}->logcroak("widget undefined") unless $w;
 
     my %widgets_enabled = map { $_, 1 } @{$keepit};
     my %class           = map { $_, 1 }
@@ -511,8 +510,8 @@ sub populate_widgets {
     return unless ( UNIVERSAL::isa( $w, 'Wx::Window' ) );
     my @c = $w->GetChildren;
     if ( !defined $no_warn && scalar @c == 0 ) {
-        carp
-            "populate_widgets received a container widget without any children";
+        $self->{log}->logcarp(
+            "populate_widgets received a container widget without any children");
     }
     for my $c ( $w->GetChildren ) {
         my $id   = $c->GetName;
