@@ -3,8 +3,9 @@ use strict;
 use warnings;
 use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Dbc::Schema;
-use Log::Log4perl;
-Log::Log4perl->init("log.conf");
+use Log::Log4perl qw(:easy);
+Log::Log4perl->easy_init($DEBUG);
+#Log::Log4perl->init("log.conf");
 use Forms::Langues;
 use DataAccess::Dbc::Service;
 #use Devel::Cycle;
