@@ -3,8 +3,10 @@ use strict;
 use warnings;
 use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use DBI;
-use Log::Log4perl;
-Log::Log4perl->init("log.conf");
+use Log::Log4perl qw(:easy);
+Log::Log4perl->easy_init($DEBUG);
+#use Log::Log4perl;
+#Log::Log4perl->init("log.conf");
 use Forms::Langues;
 use DataAccess::Dbi::Service;
 #use Devel::Cycle;
