@@ -11,11 +11,11 @@ use warnings;
 
 =head1 VERSION
 
-version  0.011 but see version at the end of MYMETA.yml to check that I'm correct here...
+version  0.012 but see version at the end of MYMETA.yml to check that I'm correct here...
 
 =cut
 
-our $VERSION     = '0.011';
+our $VERSION     = '0.012';
 $VERSION = eval $VERSION;
 
 1;
@@ -36,13 +36,15 @@ On windows use nmake or dmake instead of make.
 
 The following modules are required in order to use Wx::Perl::Linker
 
-	Gtk2::Ex::DbLinker::DbTools => 0.105,
+	Gtk2::Ex::DbLinker::DbTools => latest version (see README),
 	Data::Dumper => 2.154,
 	DateTime::Format::Strptime => 1.5,
 	Test::More => 1,
 	Wx => 0.99,
 	Log::Log4perl => 1.41
 	DBD::SQLite'	=> 1.46
+    Scalar::Util => 1.45
+    Class::InsideOut => 1.13
 
 Install one of Rose::DB::Object or DBIx::Class if you want to use these orm to access your data.
 
@@ -63,7 +65,7 @@ Create a Gtk2::Ex::DbLinker::xxxDataManager object that contains the rows to dis
 =item * 
 
 Create xrc resource files to construct the gui: Wx windows and controls.
-It is required is that you name your widgets the same as the fields in your data source.
+It is required that you name your widgets the same as the fields in your data source.
 
 
 =item * 
@@ -111,7 +113,7 @@ C<runexample_dbc.pl> uses DBIx::Class and Gtk2::Ex::DbLinker::DbcDataManager. Th
 
 =item *
 
-C<runexample_sqla.pl uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
+C<runexample_sqla.pl> uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
 
 =item *
 
@@ -128,8 +130,7 @@ L<http://sourceforge.net/projects/wx-perl-dblinker/>.
 
 =head1 AUTHOR
 
-    FranE<ccedil>ois Rappaz <rappazf@gmail.com>
-    CPAN ID: RAPPAZF
+FranE<231>ois Rappaz <rappazf@gmail.com>    CPAN ID: RAPPAZF
 
 =head1 COPYRIGHT
 
