@@ -9,8 +9,8 @@ use warnings;
 package Wx::Perl::DbLinker::Wxdatasheet;
 use Wx::Perl::DbLinker;
 our $VERSION = $Wx::Perl::DbLinker::VERSION;
-use Carp qw(croak confess carp);
-use Data::Dumper;
+#use Carp qw(croak confess carp);
+# use Data::Dumper;
 use Wx qw(:everything);
 use base qw(Wx::Grid);
 use Gtk2::Ex::DbLinker::DatasheetHelper;
@@ -205,7 +205,7 @@ sub _setup_grid {
                 );
                 $self->{log}->debug( "col: ", $col, " label: ", $label );
                 $self->{log}->debug( "cell editor: " . ref $field->{editor} );
-                croak("\$col undef") unless defined $col;
+                $self->{log}->logcroak("\$col undef") unless defined $col;
                 $self->SetColLabelValue( $col, $label );
                 if ( defined $field->{size} ) {
                     $self->SetColSize( $col, $field->{size} );    #if ($r==0);
@@ -319,7 +319,7 @@ sub get_column_value {
         #my $aref = $self->{combo_cur}->{$sql_fieldname};
         my $aref = $self->{combo_cur};
         $value = $aref->[$current_row];
-        $self->{log}->debug( "get_column_value combo_cur : ", Dumper $aref);
+        # $self->{log}->debug( "get_column_value combo_cur : ", Dumper $aref);
         $self->{log}
             ->debug( "get_column_value is combo return  : " . $value );
     }
@@ -453,7 +453,7 @@ sub apply {
                 $val = $self->_find_index( $status_lab, (STATUS_LAB) );
             }
             else {
-              $self->{log}->debug(Dumper $self->{combo_cur}); #->{$name}
+                # $self->{log}->debug(Dumper $self->{combo_cur}); #->{$name}
                 if ( $self->_is_combo($col) ) {
                     #my $aref = $self->{combo_cur}->{$name};
                     my $aref = $self->{combo_cur};
@@ -606,7 +606,7 @@ sub _combo_edited {
 
     # die(Dumper $aref);
     my @a = @{$aref};
-    $self->{log}->debug( "id: " . Dumper($id) );
+    $self->{log}->debug( "id: " . $id );
     $self->{log}->debug( "new value:  "
             . $new_text
             . " index: "
@@ -665,8 +665,8 @@ use Wx qw(:everything);
 
 use Wx::Grid;
 use base qw(Wx::PlGridTable);
-use Carp qw(croak confess carp);
-use Data::Dumper;
+#use Carp qw(croak confess carp);
+# use Data::Dumper;
 
 #the datamanager holding data from the database populate the grid
 #data in the grid are stored in $$self{array}[$row][$col]
@@ -739,7 +739,7 @@ sub GetValue {
             $result = $$self{array}->[$row][$col];
         }
         else {
-            confess("array undef");
+            $self->{log}->logconfess("array undef");
         }
 
         my $fname = $self->{fields}[$col]->{name};
@@ -748,7 +748,7 @@ sub GetValue {
 
     }
     else {
-        carp( "Index out of bound in DBGridTable: " . $row . " : " . $col );
+        $self->{log}->logcarp( "Index out of bound in DBGridTable: " . $row . " : " . $col );
     }
 
     $result = '' unless defined $result;
@@ -761,9 +761,9 @@ sub SetValue {
     my ( $self, $row, $col, $value ) = @_;
 
 #$self->{log}->debug ("SetValue GNR: " . $self->GetNumberRows . " pos to add to is " . $row) ;
-    confess("Array out of bounds too much rows")
+    $self->{log}->logconfess("Array out of bounds too much rows")
         unless ( $row < $self->GetNumberRows );
-    confess("Array out of bounds too much cols")
+    $self->{log}->logconfess("Array out of bounds too much cols")
         unless ( $col < $self->GetNumberCols );
 
     my $fname = $self->{fields}->[$col]->{name};
@@ -791,7 +791,7 @@ sub GetPlData_todel {
 sub SetPlData_todel {
     my ( $self, $row, $col, $data ) = @_;
 
-    croak("Array out of bounds")
+    $self->{log}->logcroak("Array out of bounds")
       unless ( $row < $self->GetNumberRows && $col < $self->GetNumberCols );
     $$self{array}->[$row][$col]->SetPlData($data);
 }
@@ -1079,7 +1079,7 @@ This gets the RdbDataManager that will populate the datasheet
 
 
 If the grid hold combo(s), the RdbDataManagers for those combo rows are created:
-     
+
 		 $combodata = Gtk2::Ex::DbLinker::DbcDataManager->new(
 				rs => $self->{schema}->resultset('Country')->search_rs(undef, { order_by => 'country'} ),
 			);
@@ -1094,11 +1094,11 @@ The Wxdatasheet object with the columns description is created:
 					renderer => "combo",	header_markup => "Country", data_manager=> $combodata, fieldnames => ["countryid", "country"],
 					},	
 				   {name=>"langid", renderer=>"hidden"},
-				
+
 		        	],
 			after_update => => sub{ on_after_update($self, $self->{sf_list}->{dnav}, $list, "grid"); },
 		borders_size => [20, 25], #horizontal: row_1: heigth, vertical : col_1: witdh
-		
+
 	    );
 
 C<$scrolledwindow> is the widget that will received the grid. It is created before the grid creation:
@@ -1224,7 +1224,7 @@ It can be passed to the Wxdatasheet constructor with
 		             ], 
 		  data_manager =>  ...
 		  }
-		 
+
 
 =back
 
@@ -1303,7 +1303,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2016-2017 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
