@@ -7,10 +7,10 @@ our $VERSION = $Wx::Perl::DbLinker::VERSION;
 use strict;
 use warnings;
 use parent 'Gtk2::Ex::DbLinker::AbForm';
-use Carp qw(croak confess carp);
 
+# use Carp qw(croak confess carp);
 #use DateTime::Format::Strptime;
-use Data::Dumper;
+#use Data::Dumper;
 use Scalar::Util qw( weaken );
 use Wx qw[:everything];
 
@@ -232,7 +232,7 @@ sub _init {
 
     $self->_bind_on_changed;
     $self->_set_recordspinner;
-    croak __PACKAGE__ . ": a data manager is required"
+    $log{$id }->logcroak("A data manager is required")
       unless ( defined $self->_dman );
     $self->_dman->set_row_pos(0);
 }
@@ -257,7 +257,7 @@ sub add_combo_values {
     my $wref       = ref $w;
     my @supp_class = (qw/Wx::ComboBox Wx::ListBox/);
     my %supported  = map { $_ => 1 } @supp_class;
-    confess(
+    $log{$id }->logconfess(
         "only " . join( " ", @supp_class ) . " supported by add_combo_values" )
       unless ( $supported{$wref} );
 
@@ -354,18 +354,18 @@ sub add_combo {
             $self->_datawidgetsName( $combo->{id}, $name);
         } else {
             $log{ $id }->debug( "cols: " . join( " ", @cols ) );
-            confess "no widget found for combo " . $combo->{id};
+            $log{$id }->logconfess( "no widget found for combo " . $combo->{id});
         }
     }
 
     $log{ $id }->debug( "cols: " . join( " ", @cols ) );
     my $w = $self->_datawidgets( $combo->{id} );
-    confess( 'no widget found for combo ' . $combo->{id} ) unless ($w);
+    $log{$id }->logconfess( 'no widget found for combo ' . $combo->{id} ) unless ($w);
 
     $w->Clear;
 
     #my @col = @{$self->{cols}};
-    croak("no fields found for combo $combo->{id}") unless (@cols);
+    $log{$id }->logcroak("no fields found for combo $combo->{id}") unless (@cols);
     my $lastfield = @cols;
 
     #the column to show is either the first (pos 0) if it's the only column or
@@ -428,7 +428,7 @@ sub add_combo {
                 } elsif (
                     !( $name eq "Wx::ComboBox" || $name eq "Wx::ListBox" ) )
                 {
-                    confess("add_combo: $name is not supported");
+                    $log{$id }->logconfess("add_combo: $name is not supported");
                 }
 
       #else {$log{ $id }->error("add_combo: $name is not supported" ); return;}
@@ -626,7 +626,7 @@ sub _set_entry {
 #$w->set_text( $x ) ;
 # SetValue generates a wxEVT_TEXT event. To avoid this you can use ChangeValue() instead.
 #$self->{hecols}->{$id} ? $w->SetValue($x) && $log{ $id }->debug("SetValue called") : $w->ChangeValue($x);
-        confess("id undef") unless ( defined $id );
+        $log{$id }->logconfess("id undef") unless ( defined $id );
         #if ( $self->{hecols}->{$id} ) {
         if ( $is_ecols{ $ido }->{$id} ) {
             $w->SetValue($x);
@@ -679,7 +679,7 @@ sub _set_combo {
 
         $w->SetItemState( $item, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED );
     } elsif ( $name eq "Wx::ComboBox" || $name eq "Wx::ListBox" ) {
-        confess( "undef datawidgetsPos  for ", $id )
+        $log{$id }->logconfess( "undef datawidgetsPos  for ", $id )
         unless ( $datawidgets_pos{ $ido }->{$id} );
         #unless ( $self->{datawidgetsPos}->{$id} );
         #my %idpos = %{ $self->{datawidgetsPos}->{$id} };
@@ -735,7 +735,7 @@ sub _on_combo_newval {
 sub _get_combobox_selectedvalue {
     my ( $self, $id ) = @_;
      my $ido = id $self;
-    confess("id undef") unless ( defined $id );
+    $log{$id }->logconfess("id undef") unless ( defined $id );
    
     my $w    = $self->_datawidgets( $id );
     my $name = $self->_datawidgetsName( $id );
@@ -815,7 +815,7 @@ sub _on_selected {
     if ( $self->_datawidgetsName( $id  ) eq "Wx::ListCtrl" ) {
         $datawidgets_value{ $ido }->{$id} = $event->GetText;
     } else {
-        croak(  "_on_selected not implemented for $id ("
+        $log{$id }->logcroak(  "_on_selected not implemented for $id ("
               . $self->_datawidgetsName($id)
               . ")" );
     }
@@ -939,7 +939,7 @@ In the main form:
 	}
 
 In the subform_a module
-	
+
     sub synchronize_with {
 	my ($self,$value) = @_;
 	my $data = Rdb::Product::Manager->get_product(with_objects => ['seller_product'], query => ['seller_product.no_seller' => {eq => $value}]);
@@ -1099,7 +1099,7 @@ C<datawidgets_changed> is a hash ref having the field's name as keys and a code
 		$self->{sform} = Wx::Perl::DbLinker::Wxform->new(
 			...
 			datawidgets_changed => {langid=> sub{ on_langid_changed(@_, $self) } },
-			
+
 		);
 
 		sub on_langid_changed {
@@ -1151,11 +1151,17 @@ This method can also be called as a class method, when the underlying form is no
 
 Return an hash ref of { line number =>  first column value } for combo_name. First line is 0.
 
-=head2 C<update();> See L<Gtk2::Ex::DbLinker::AbForm/update()>
+=head2 C<update();> 
 
-=head2 C<get_data_manager();>  See L<Gtk2::Ex::DbLinker::AbForm/get_data_manager()>
+See L<Gtk2::Ex::DbLinker::AbForm/update()>
 
-=head2 C<set_data_manager( $dman ) > See L<Gtk2::Ex::DbLinker::AbForm/set_data_manager( $dman )>
+=head2 C<get_data_manager();>  
+
+See L<Gtk2::Ex::DbLinker::AbForm/get_data_manager()>
+
+=head2 C<set_data_manager( $dman ) > 
+
+See L<Gtk2::Ex::DbLinker::AbForm/set_data_manager( $dman )>
 
 =head2 C<get_widget_value ( $widget_id );>
 
@@ -1204,7 +1210,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015 by F. Rappaz.  All rights reserved.
+Copyright (c) 2015-2017 by F. Rappaz.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
